distance.info: Pairwise distances of spatial coordinates
Description
A range of descriptive statistics on the distribution of the pairwise distances between observations.
Usage
distance.info(data)
Value
A list containing:
distmatrix
A matrix containing the pairwise Euclidean distances between
all given locations.
distset
A vector containing the pairwise Euclidean distances.
The elements equal the upper (or lower) triangle minus the diagonal
of the distance matrix. If the input dataset has n rows, distset contains \(n(n-1)/2\) distances.
distsummary
A summary containing the minimum, 1st quartile, median, mean,
3rd quartile and maximum of the distset.
maxdist
The maximal distance.
Moreover, the function prints a histogram of the pairwise distances saved in the list entry distset.
Arguments
data
data A data frame or matrix containing
the x-coordinates in meters in the first column,
the y-coordinates in meters in the second column,
and the values of the attribute of interest in the third column.
Additional columns are ignored.