Two alternative approaches for the input of the arguments:
1. Provide the arguments
vario.mod.output (output object from vario.mod function) and
mod.nr (number of the model in the infotable).
2. Provide the necessary information manually, namely
par.est (vector with estimated nugget, partial sill and shape parameters),
data (used to estimate the semi-variogram model parameters),
max.dist (semi-variogram parameter, numeric of length 1) and
nbins (semi-variogram parameter, numeric of length 1).
Filtered bootstrap method:
For the semi-variogram model parameter estimation, the weighted least squares method is used
in order to make the numerical calculation possible for large sample sizes.
A filter is set up within the bootstrapping process to remove all
bootstrap estimates for which the estimation algorithm for the semi-variogram
model parameters did not converge.
The parameter standard errors are estimated using the generalized bootstrap
method with check-based filtering.
The semi-variogram structure from the given model is used to remove the
spatial correlation structure within the original dataset. Then,
classical bootstrap sampling with replacement is used to generate B
bootstrap samples from the uncorrelated data.
Each bootstrap sample inherits the correlation structure back and is used to estimate
the nugget effect, partial sill and shape parameter for an exponential model.
Within the bootstrap repetitions, a test is performed to check whether
the estimated parameters lie within a probable range.
If the total variance of the bootstrap model exceeds the empirical variance
of the data times the treshold factor \(\tau\), ie.
$$c_{0 b}^* + \sigma_{0 b}^{2*} > \tau \widehat{Var(\mathbf{z})}$$
for the bth bootstrap estimate, it is discarded. Otherwise, it is saved.
This procedure is performed until B bootstrap estimates have aggregated.
The empirical standard deviation calculated from the bootstrap estimates provides the
uncertainty estimate for each parameter.
Details about the algorithm used to obtain standard errors for the parameters
of the exponential semi-variogram model are provided in dyck_sv_ses;textualEgoCor.
Reproducibility:
In order to generate reproducible bootstrap results, set a random seed with the command set.seed()
before using the par.uncertainty function.